@@ -40,7 +40,7 @@ mod tests {
         reset();
 
         assert_cli!("alias", "unset", "tiny", "my/alias");
-        assert_cli_snapshot!("aliases", @r###"
+        assert_cli_snapshot!("aliases", @r#"
         java  lts          21   
         node  lts          20   
         node  lts-argon    4    
@@ -54,7 +54,7 @@ mod tests {
         node  lts-iron     20   
         tiny  lts          3.1.0
         tiny  lts-prev     2.0.0
-        "###);
+        "#);
 
         reset();
     }
