@@ -17,10 +17,23 @@ pub struct ConfigLs {
     /// Do not print table header
     #[clap(long, alias = "no-headers", verbatim_doc_comment)]
     pub no_header: bool,
+
+    /// Output in JSON format
+    #[clap(short = 'J', long, verbatim_doc_comment)]
+    pub json: bool,
 }
 
 impl ConfigLs {
     pub fn run(self) -> Result<()> {
+        if self.json {
+            self.display_json()?;
+        } else {
+            self.display()?;
+        }
+        Ok(())
+    }
+
+    fn display(&self) -> Result<()> {
         let rows = CONFIG
             .config_files
             .values()
@@ -30,12 +43,38 @@ impl ConfigLs {
         table::default_style(&mut table, self.no_header);
         table.with(Modify::new(Columns::last()).with(Width::truncate(40).suffix("…")));
         miseprintln!("{table}");
+        Ok(())
+    }
 
+    fn display_json(&self) -> Result<()> {
+        let array_items = CONFIG
+            .config_files
+            .values()
+            .map(|cf| {
+                let c: &dyn ConfigFile = cf.as_ref();
+                let mut item = serde_json::Map::new();
+                item.insert(
+                    "path".to_string(),
+                    serde_json::Value::String(c.get_path().to_string_lossy().to_string()),
+                );
+                let plugins = c
+                    .to_tool_request_set()
+                    .unwrap()
+                    .list_plugins()
+                    .into_iter()
+                    .map(|s| serde_json::Value::String(s.to_string()))
+                    .collect::<Vec<serde_json::Value>>();
+                item.insert("tools".to_string(), serde_json::Value::Array(plugins));
+
+                item
+            })
+            .collect::<serde_json::Value>();
+        miseprintln!("{}", serde_json::to_string_pretty(&array_items)?);
         Ok(())
     }
 }
 
-fn format_plugin_cell(s: String) -> String {
+fn format_tools_cell(s: String) -> String {
     match s.is_empty() {
         true => style("(none)").italic().dim().to_string(),
         false => style(s).dim().to_string(),
@@ -46,7 +85,7 @@ fn format_plugin_cell(s: String) -> String {
 #[tabled(rename_all = "PascalCase")]
 struct Row {
     path: String,
-    plugins: String,
+    tools: String,
 }
 
 impl From<&dyn ConfigFile> for Row {
@@ -54,8 +93,8 @@ impl From<&dyn ConfigFile> for Row {
         let path = display_path(cf.get_path());
         let ts = cf.to_tool_request_set().unwrap();
         let plugins = ts.list_plugins().into_iter().join(", ");
-        let plugins = format_plugin_cell(plugins);
-        Self { path, plugins }
+        let tools = format_tools_cell(plugins);
+        Self { path, tools }
     }
 }
 
@@ -80,4 +119,10 @@ mod tests {
         ~/config/config.toml      (none)
         "###);
     }
+
+    #[test]
+    fn test_config_ls_json() {
+        reset();
+        assert_cli_snapshot!("cfg", "--json");
+    }
 }
