@@ -1,6 +1,5 @@
 use duct::Expression;
-use eyre::Result;
-use eyre::WrapErr;
+use eyre::{Result, WrapErr};
 use serde_derive::Deserialize;
 
 use crate::config::Config;
@@ -51,9 +50,14 @@ fn env_cmd() -> Expression {
 
 #[cfg(test)]
 mod tests {
+    use pretty_assertions::assert_str_eq;
+
     use crate::cli::tests::grep;
+    use crate::test::reset;
+
     #[test]
     fn test_direnv_exec() {
+        reset();
         let stdout = assert_cli!("direnv", "exec");
         assert_str_eq!(grep(stdout, "JDXCODE_TINY="), "JDXCODE_TINY=3.1.0");
     }
