@@ -7,6 +7,7 @@ use std::sync::Mutex;
 use std::time::SystemTime;
 
 use super::args::ToolArg;
+use crate::cli::Cli;
 use crate::cmd::CmdLineRunner;
 use crate::config::{CONFIG, SETTINGS};
 use crate::errors::Error;
@@ -52,16 +53,20 @@ use nix::sys::signal::SIGTERM;
 ///     EOF
 ///     $ mise run build
 #[derive(Debug, clap::Args)]
-#[clap(visible_alias = "r", verbatim_doc_comment, after_long_help = AFTER_LONG_HELP)]
+#[clap(visible_alias = "r", verbatim_doc_comment, disable_help_flag = true, after_long_help = AFTER_LONG_HELP)]
 pub struct Run {
     /// Tasks to run
     /// Can specify multiple tasks by separating with `:::`
     /// e.g.: mise run task1 arg1 arg2 ::: task2 arg1 arg2
-    #[clap(verbatim_doc_comment, default_value = "default")]
+    #[clap(
+        allow_hyphen_values = true,
+        verbatim_doc_comment,
+        default_value = "default"
+    )]
     pub task: String,
 
     /// Arguments to pass to the tasks. Use ":::" to separate tasks.
-    #[clap(allow_hyphen_values = true)]
+    #[clap(allow_hyphen_values = true, trailing_var_arg = true)]
     pub args: Vec<String>,
 
     /// Change to this directory before executing the command
@@ -117,6 +122,14 @@ pub struct Run {
 
 impl Run {
     pub fn run(self) -> Result<()> {
+        if self.task == "-h" {
+            self.get_clap_command().print_help()?;
+            return Ok(());
+        }
+        if self.task == "--help" {
+            self.get_clap_command().print_long_help()?;
+            return Ok(());
+        }
         SETTINGS.ensure_experimental("`mise run`")?;
         time!("run init");
         let task_list = self.get_task_lists()?;
@@ -126,6 +139,14 @@ impl Run {
         Ok(())
     }
 
+    fn get_clap_command(&self) -> clap::Command {
+        Cli::command()
+            .get_subcommands()
+            .find(|s| s.get_name() == "run")
+            .unwrap()
+            .clone()
+    }
+
     fn get_task_lists(&self) -> Result<Vec<Task>> {
         once(&self.task)
             .chain(self.args.iter())
@@ -149,7 +170,7 @@ impl Run {
                     .collect_vec();
                 if tasks.is_empty() {
                     if t != "default" {
-                        err_no_task(&t)?;
+                        self.err_no_task(&t)?;
                     }
 
                     Ok(vec![self.prompt_for_task()?])
@@ -205,7 +226,7 @@ impl Run {
                         trace!("running task: {task}");
                         if let Err(err) = self.run_task(&env, &task) {
                             let prefix = task.estyled_prefix();
-                            info_unprefix!("{prefix} {} {err}", style::ered("ERROR"),);
+                            eprintln!("{prefix} {} {err}", style::ered("ERROR"),);
                             let _ = tx_err.send((task.clone(), Error::get_exit_status(&err)));
                         }
                     }
@@ -234,13 +255,13 @@ impl Run {
 
         if let Some((task, status)) = self.failed_tasks.lock().unwrap().first() {
             let prefix = task.estyled_prefix();
-            info_unprefix!("{prefix} {} task failed", style::ered("ERROR"));
+            eprintln!("{prefix} {} task failed", style::ered("ERROR"));
             exit(*status);
         }
 
         if self.timings && num_tasks > 1 {
             let msg = format!("finished in {}", time::format_duration(timer.elapsed()));
-            info!("{}", style::edim(msg));
+            eprintln!("{}", style::edim(msg));
         };
 
         time!("paralellize_tasks done");
@@ -251,7 +272,7 @@ impl Run {
     fn run_task(&self, env: &BTreeMap<String, String>, task: &Task) -> Result<()> {
         let prefix = task.estyled_prefix();
         if !self.force && self.sources_are_fresh(task) {
-            info_unprefix_trunc!("{prefix} sources up-to-date, skipping");
+            eprintln!("{prefix} sources up-to-date, skipping");
             return Ok(());
         }
 
@@ -283,9 +304,8 @@ impl Run {
         }
 
         if self.timings {
-            miseprintln!(
-                "{} finished in {}",
-                prefix,
+            eprintln!(
+                "{prefix} finished in {}",
                 time::format_duration(timer.elapsed())
             );
         }
@@ -304,8 +324,8 @@ impl Run {
         prefix: &str,
     ) -> Result<()> {
         let script = script.trim_start();
-        let cmd = style::ebold(format!("$ {script}")).bright().to_string();
-        info_unprefix_trunc!("{prefix} {cmd}");
+        let cmd = trunc(&style::ebold(format!("$ {script}")).bright().to_string());
+        eprintln!("{prefix} {cmd}");
 
         if script.starts_with("#!") {
             let dir = tempfile::tempdir()?;
@@ -376,8 +396,8 @@ impl Run {
         }
 
         let cmd = format!("{} {}", display_path(file), args.join(" "));
-        let cmd = style::ebold(format!("$ {cmd}")).bright().to_string();
-        info_unprefix_trunc!("{prefix} {cmd}");
+        let cmd = trunc(&style::ebold(format!("$ {cmd}")).bright().to_string());
+        eprintln!("{prefix} {cmd}");
 
         self.exec(&command, &args, task, &env, prefix)
     }
@@ -547,30 +567,31 @@ impl Run {
         // TODO
         Ok(())
     }
-}
 
-fn err_no_task(name: &str) -> Result<()> {
-    if let Some(cwd) = &*dirs::CWD {
-        let includes = CONFIG.task_includes_for_dir(cwd);
-        let path = includes
-            .iter()
-            .map(|d| d.join(name))
-            .find(|d| d.is_file() && !file::is_executable(d));
-        if let Some(path) = path {
-            warn!(
-                "no task {} found, but a non-executable file exists at {}",
-                style::ered(name),
-                display_path(&path)
-            );
-            let yn =
-                prompt::confirm("Mark this file as executable to allow it to be run as a task?")?;
-            if yn {
-                file::make_executable(&path)?;
-                info!("marked as executable, try running this task again");
+    fn err_no_task(&self, name: &str) -> Result<()> {
+        if let Some(cwd) = &*dirs::CWD {
+            let includes = CONFIG.task_includes_for_dir(cwd);
+            let path = includes
+                .iter()
+                .map(|d| d.join(name))
+                .find(|d| d.is_file() && !file::is_executable(d));
+            if let Some(path) = path {
+                warn!(
+                    "no task {} found, but a non-executable file exists at {}",
+                    style::ered(name),
+                    display_path(&path)
+                );
+                let yn = prompt::confirm(
+                    "Mark this file as executable to allow it to be run as a task?",
+                )?;
+                if yn {
+                    file::make_executable(&path)?;
+                    info!("marked as executable, try running this task again");
+                }
             }
         }
+        bail!("no task {} found", style::ered(name));
     }
-    bail!("no task {} found", style::ered(name));
 }
 
 fn is_glob_pattern(path: &str) -> bool {
@@ -672,6 +693,11 @@ enum TaskOutput {
     Interleave,
 }
 
+fn trunc(msg: &str) -> String {
+    let msg = msg.lines().next().unwrap_or_default();
+    console::truncate_str(msg, *env::TERM_WIDTH, "…").to_string()
+}
+
 #[cfg(test)]
 mod tests {
     use insta::assert_snapshot;
