@@ -54,22 +54,23 @@ mod tests {
         all_compile = false
         always_keep_download = true
         always_keep_install = true
-        asdf = true
         asdf_compat = false
         cache_prune_age = "0"
-        cargo_binstall = true
         color = true
-        disable_default_shorthands = false
+        disable_backends = []
+        disable_default_registry = false
         disable_hints = []
         disable_tools = []
         experimental = true
+        fetch_remote_versions_cache = "1h"
+        fetch_remote_versions_timeout = "10s"
         go_default_packages_file = "~/.default-go-packages"
         go_download_mirror = "https://dl.google.com/go"
         go_repo = "https://github.com/golang/go"
         go_set_gopath = false
         go_set_goroot = true
         go_skip_checksum = false
-        http_timeout = 30
+        http_timeout = "30s"
         jobs = 4
         legacy_version_file = true
         legacy_version_file_disable_tools = []
@@ -77,7 +78,6 @@ mod tests {
         not_found_auto_install = true
         paranoid = false
         pin = false
-        pipx_uvx = false
         plugin_autoupdate_last_check_duration = "20m"
         python_default_packages_file = "~/.default-python-packages"
         quiet = false
@@ -85,11 +85,16 @@ mod tests {
         trusted_config_paths = []
         use_versions_host = true
         verbose = true
-        vfox = false
         yes = true
 
+        [cargo]
+        binstall = true
+
         [node]
 
+        [pipx]
+        uvx = false
+
         [python]
         default_packages_file = "~/.default-python-packages"
         pyenv_repo = "https://github.com/pyenv/pyenv.git"
