@@ -14,3 +14,11 @@ pub fn list_releases(repo: &str) -> eyre::Result<Vec<GithubRelease>> {
     let url = format!("https://api.github.com/repos/{}/releases", repo);
     crate::http::HTTP_FETCH.json(url)
 }
+
+pub fn get_release(repo: &str, tag: &str) -> eyre::Result<GithubRelease> {
+    let url = format!(
+        "https://api.github.com/repos/{}/releases/tags/{}",
+        repo, tag
+    );
+    crate::http::HTTP_FETCH.json(url)
+}
