@@ -10,8 +10,7 @@ use tokio::runtime::Runtime;
 use url::Url;
 
 use crate::cli::version;
-use crate::config::Settings;
-use crate::env::MISE_FETCH_REMOTE_VERSIONS_TIMEOUT;
+use crate::config::SETTINGS;
 use crate::file::display_path;
 use crate::ui::progress_report::SingleReport;
 use crate::{env, file};
@@ -20,11 +19,16 @@ use crate::{env, file};
 pub static HTTP_VERSION_CHECK: Lazy<Client> =
     Lazy::new(|| Client::new(Duration::from_secs(3)).unwrap());
 
-pub static HTTP: Lazy<Client> =
-    Lazy::new(|| Client::new(Duration::from_secs(Settings::get().http_timeout)).unwrap());
+pub static HTTP: Lazy<Client> = Lazy::new(|| {
+    let duration = humantime::parse_duration(&SETTINGS.http_timeout)
+        .unwrap_or_else(|_| Duration::from_secs(SETTINGS.http_timeout.parse().unwrap()));
+    Client::new(duration).unwrap()
+});
 
-pub static HTTP_FETCH: Lazy<Client> =
-    Lazy::new(|| Client::new(*MISE_FETCH_REMOTE_VERSIONS_TIMEOUT).unwrap());
+pub static HTTP_FETCH: Lazy<Client> = Lazy::new(|| {
+    Client::new(humantime::parse_duration(&SETTINGS.fetch_remote_versions_timeout).unwrap())
+        .unwrap()
+});
 
 #[derive(Debug)]
 pub struct Client {
