@@ -213,6 +213,10 @@ impl Plugin for AsdfPlugin {
         &self.name
     }
 
+    fn path(&self) -> PathBuf {
+        self.plugin_path.clone()
+    }
+
     fn get_plugin_type(&self) -> PluginType {
         PluginType::Asdf
     }
